﻿using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using GenericParsing;
/*Add this line to use PowerPointWriter*/
using SoftArtisans.OfficeWriter.PowerPointWriter;

namespace EmployeeTraining.templates
{
    public partial class Part3 : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {

        }

        protected void RunReport_Click(object sender, EventArgs e)
        {
            try
            {
                //------------------------------------------------------------------
                //Part 3 - Copy Slide  
                //Pass the presentation from Template to Application
                PowerPointApplication ppta = new PowerPointApplication();
                Presentation pres = ppta.Open(Page.MapPath("//templates//part3_template.pptx"));
                
                //Create a copy of slide 8 in our presentation and add it to the end of the presnetation
                //We can access the slide using the 0 indexed position in our presentation
                Slide slideToCopy = pres.Slides[7];
                pres.Slides.CopySlide(slideToCopy, (pres.Slides.Count));

                //Create 3 copies leaving us with 4 matching slides
                pres.Slides.CopySlide(slideToCopy, (pres.Slides.Count));
                pres.Slides.CopySlide(slideToCopy, (pres.Slides.Count));

                //pass the presentation to Template
                using (PowerPointTemplate pptt = new PowerPointTemplate())
                {
                    pptt.Open(ppta, pres);

                    //-----------------------------------------------------------------------------------------------------------
                    //This is the code from parts 1 and 2 of the Employee Training tutorial
                    //Code from Part 1
                    DataBindingProperties dataProps = pptt.CreateDataBindingProperties();
                    string[] columnNamesArray = {"Logo"};
                    Byte[] logoArray = System.IO.File.ReadAllBytes((Page.MapPath("//data//logo.png")));
                    object[] valuesArray = {logoArray};
                    pptt.BindData(valuesArray, columnNamesArray, "Company", dataProps);
                    string[] employeeColNames = {"Name", "Team"};
                    object[] employeeValues = {"Amy Alberts", "Development"};
                    pptt.BindData(employeeValues, employeeColNames, "Employee", dataProps);
                    DataTable teamData = GetCSVData((Page.MapPath("//data//Team.csv")));
                    pptt.BindData(teamData, "Team", dataProps);
                    //Code from Part 2
                    DataTable dtCompanyHistory = GetCSVData(Page.MapPath("//data//CompanyHistory.csv"));
                    dataProps.MaxRowsPerSlide = 8;
                    pptt.BindData(dtCompanyHistory, "CompanyHistory", dataProps);
                    DataTable dtProducts = GetCSVData(Page.MapPath("//data//Products.csv"));
                    DataBindingProperties dataProps2 = pptt.CreateDataBindingProperties();
                    dataProps2.MaxRowsPerSlide = 2;
                    pptt.BindData(dtProducts, "Products", dataProps2);
                    //-----------------------------------------------------------------------------------------------------------

                    //add the data from part 3
                    //All of our slides contain the data markers Department.TrainingItem and TrainingItems.Detail
                    //We will make an array of column names to use for all of the data binding calls
                    string[] titleCol = {"TrainingItem"};

                    //Get the data for the first slide in the 'Your Team' section
                    //This will be 'Team Members'
                    //Data for the TrainingItem data source
                    object[] titleArrayTeam = {"Team Members"};
                    //Get the Team members data
                    DataTable dtTeamMembers = GetCSVData(Page.MapPath("//data//TeamMembers.csv"));
                    //Set Slide to be the 8th slide in our presentation - we can use an existing DataBindingProperties object
                    dataProps.Slide = 7;
                    //Bind the Data
                    //The Department data source binds the text 'Team Members' to the slide
                    pptt.BindData(titleArrayTeam, titleCol, "Department", dataProps);
                    //TrainingItems binds the data from the csv
                    pptt.BindData(dtTeamMembers, "TrainingItems", dataProps);

                    //repeat this process for the 3 remining slides
                    //The next slide will be 'Agile Development / Scrum'
                    //Data for the TrainingItem data source
                    object[] titleArrayAgile = {"Agile Development / Scrum"};
                    DataTable dtAgile = GetCSVData(Page.MapPath("//data//Agile.csv"));
                    //Set Slide to be the 9th slide in our presentation - we can use an existing DataBindingProperties object
                    dataProps.Slide = 8;
                    //Bind the Data
                    pptt.BindData(titleArrayAgile, titleCol, "Department", dataProps);
                    pptt.BindData(dtAgile, "TrainingItems", dataProps);

                    //The next slide will be 'REsources and Utilities'
                    //Data for the TrainingItem data source
                    object[] titleArrayResources = {"Resources and Utilities"};
                    DataTable dtResources = GetCSVData(Page.MapPath("//data//Resources.csv"));
                    //Set Slide to be the 10th slide in our presentation - we can use an existing DataBindingProperties object
                    dataProps.Slide = 9;
                    //Bind the Data
                    pptt.BindData(titleArrayResources, titleCol, "Department", dataProps);
                    pptt.BindData(dtResources, "TrainingItems", dataProps);

                    //The final slide will be 'Expectations'
                    //Data for the TrainingItem data source
                    object[] titleArrayExpectations = {"Expectations"};
                    DataTable dtExpectations = GetCSVData(Page.MapPath("//data//Expectations.csv"));
                    //Set Slide to be the last slide in our presentation - we can use an existing DataBindingProperties object
                    dataProps.Slide = 10;
                    //Bind the Data
                    pptt.BindData(titleArrayExpectations, titleCol, "Department", dataProps);
                    pptt.BindData(dtExpectations, "TrainingItems", dataProps);

                    pptt.Process();

                    pptt.Save(Page.Response, "part3_OutPut.pptx", false);
                }

            }
            catch (Exception ex)
            {
                ErrorLabel.Visible = true;
                if (ex.Message.Contains("General license key exception"))
                {
                    ErrorLabel.Text = "OfficeWriter does not appear to be" +
                       " installed on this machine. If you have not " +
                       "purchased OfficeWriter, you can download the " +
                       "evaluation version here: " +
                       "http://www.officewriter.com/officewriter-free-evaluation.aspx";
                }
                else
                {
                    ErrorLabel.Text = ex.Message;
                }

            }
        }

        #region Utility Methods
        //Uses CSV reader
        DataTable GetCSVData(string csvFileName)
        {
            DataTable dt;
            using (GenericParserAdapter parser = new GenericParserAdapter(csvFileName))
            {
                parser.ColumnDelimiter = ',';
                parser.FirstRowHasHeader = true;

                dt = parser.GetDataTable();
            }
            return dt;
        }

        #endregion


    }
}
